//
//  ContentView.swift
//  HapticFeedbackApp
//
//  Created by Gabriel Theodoropoulos.
//  https://serialcoder.dev
//

import SwiftUI

struct ContentView: View {
    @State private var lightFeedback: UIImpactFeedbackGenerator?
    @State private var mediumFeedback: UIImpactFeedbackGenerator?
    @State private var heavyFeedback: UIImpactFeedbackGenerator?
    @State private var rigidFeedback: UIImpactFeedbackGenerator?
    @State private var softFeedback: UIImpactFeedbackGenerator?
    
    var body: some View {
        VStack(spacing: 30) {
            Button("Light Feedback") {
                lightFeedback?.impactOccurred()
                lightFeedback?.prepare()
            }
            
            Button("Medium Feedback") {
                mediumFeedback?.impactOccurred()
                mediumFeedback?.prepare()
            }
            .foregroundStyle(.orange)
            
            Button("Heavy Feedback") {
                heavyFeedback?.impactOccurred()
                heavyFeedback?.prepare()
            }
            .foregroundStyle(.red)
            
            Button("Rigid Feedback") {
                rigidFeedback?.impactOccurred()
                rigidFeedback?.prepare()
            }
            .foregroundStyle(.indigo)
            
            Button("Soft Feedback") {
                softFeedback?.impactOccurred()
                softFeedback?.prepare()
            }
            .foregroundStyle(.teal)
        }
        .font(.title2)
        .fontWeight(.bold)
        .onAppear {
            lightFeedback = UIImpactFeedbackGenerator(style: .light)
            lightFeedback?.prepare()
            
            mediumFeedback = UIImpactFeedbackGenerator(style: .medium)
            mediumFeedback?.prepare()
            
            heavyFeedback = UIImpactFeedbackGenerator(style: .heavy)
            heavyFeedback?.prepare()
            
            rigidFeedback = UIImpactFeedbackGenerator(style: .rigid)
            rigidFeedback?.prepare()
            
            softFeedback = UIImpactFeedbackGenerator(style: .soft)
            softFeedback?.prepare()
        }
        .onDisappear {
            lightFeedback = nil
            mediumFeedback = nil
            heavyFeedback = nil
            rigidFeedback = nil
            softFeedback = nil
        }
    }
}

#Preview {
    ContentView()
}
